@@ -1,18 +1,25 @@
 """ESMValTool diagnostics."""
 
 from climate_ref_esmvaltool.diagnostics.climate_at_global_warming_levels import ClimateAtGlobalWarmingLevels
+from climate_ref_esmvaltool.diagnostics.cloud_radiative_effects import CloudRadiativeEffects
 from climate_ref_esmvaltool.diagnostics.ecs import EquilibriumClimateSensitivity
+from climate_ref_esmvaltool.diagnostics.enso import ENSOBasicClimatology, ENSOCharacteristics
 from climate_ref_esmvaltool.diagnostics.example import GlobalMeanTimeseries
-from climate_ref_esmvaltool.diagnostics.sea_ice_area_seasonal_cycle import SeaIceAreaSeasonalCycle
+from climate_ref_esmvaltool.diagnostics.sea_ice_area_basic import SeaIceAreaBasic
+from climate_ref_esmvaltool.diagnostics.sea_ice_sensitivity import SeaIceSensitivity
 from climate_ref_esmvaltool.diagnostics.tcr import TransientClimateResponse
 from climate_ref_esmvaltool.diagnostics.tcre import TransientClimateResponseEmissions
 from climate_ref_esmvaltool.diagnostics.zec import ZeroEmissionCommitment
 
 __all__ = [
     "ClimateAtGlobalWarmingLevels",
+    "CloudRadiativeEffects",
+    "ENSOBasicClimatology",
+    "ENSOCharacteristics",
     "EquilibriumClimateSensitivity",
     "GlobalMeanTimeseries",
-    "SeaIceAreaSeasonalCycle",
+    "SeaIceAreaBasic",
+    "SeaIceSensitivity",
     "TransientClimateResponse",
     "TransientClimateResponseEmissions",
     "ZeroEmissionCommitment",
